@@ -13,7 +13,7 @@ use Scalar::Util qw(blessed);
 use constant CHUNK_SIZE => $ENV{MOJO_CHUNK_SIZE} || 131072;
 use constant DEBUG      => $ENV{MOJO_READWRITEFORK_DEBUG} && 1;
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 our @SAFE_SIG
   = grep { !m!^(NUM\d+|__[A-Z0-9]+__|ALL|CATCHALL|DEFER|HOLD|IGNORE|MAX|PAUSE|RTMAX|RTMIN|SEGV|SETS)$! } keys %SIG;
@@ -143,7 +143,7 @@ sub _start_parent {
   $stdout_read->close_slave if blessed $stdout_read and $stdout_read->isa('IO::Pty');
 
   my $stream = Mojo::IOLoop::Stream->new($stdout_read)->timeout(0);
-  $stream->on(error => sub { $self->emit(error => "Read error: $_[1]") });
+  $stream->on(error => sub { $! != EIO && $self->emit(error => "Read error: $_[1]") });
   $stream->on(close => sub { $self->_maybe_terminate('wait_eof') });
   $stream->on(
     read => sub {
@@ -238,7 +238,7 @@ Mojo::IOLoop::ReadWriteFork - Fork a process and read/write from it
 
 =head1 VERSION
 
-0.42
+0.43
 
 =head1 SYNOPSIS
 
